@@ -474,6 +474,22 @@ class Command(PatchedTemplateCommand):
 
         return result
 
+    def _extend_implementation_strategy(self):
+        """
+        Расширение перечисления стратегий реализаций функций.
+        """
+        entity_storage = EntityStorage()
+        entity_storage.prepare()
+
+        strategies = entity_storage.entities[EntityType.STRATEGY.key]
+
+        for strategy in strategies.values():
+            if strategy['class'].key:
+                ImplementationStrategy.extend(
+                    key=strategy['class'].key.upper(),
+                    title=strategy['class'].title,
+                )
+
     def handle(self, **options):
         function_name = options.pop('name')
         target = options.pop('directory')
